import { STATUS_CODES } from 'node:http';
import { assign, pick } from 'lodash-es';
export const expressJsonErrorHandler = ({ log, extraFields } = {}) => (err, req, res, _) => {
    let status = err.status ?? err.statusCode ?? 500;
    if (status < 400) {
        status = 500;
    }
    res.status(status);
    const body = {
        status,
    };
    if (process.env.NODE_ENV !== 'production') {
        body.stack = err.stack;
    }
    if (status >= 500) {
        body.message = STATUS_CODES[status];
        if (log) {
            log({ err, req, res });
        }
        res.json(body);
        return;
    }
    assign(body, pick(err, [...(extraFields ?? []), 'message', 'code', 'name', 'type']));
    res.json(body);
};
export default expressJsonErrorHandler;
//# sourceMappingURL=index.js.map